%% This is the file l3unicode-data.def
%% generated using the script l3unicode-data.dtx.
%%
%% The data here are derived from the files
%%  - UnicodeData.txt
%%  - SpecialCasing.txt
%%  - CaseFolding.txt
%% which are maintained by the Unicode Consortium.
%%
%% Generated on 2015-03-01.
%%
\ProvidesExplFile {l3unicode-data.def} {2015/03/01} {5544} {L3 Unicode data}
\pdftex_if_engine:T
  {
    \group_begin:
      \cs_set_protected:Npn \__unicode_tmp:NN #1#2
        {
          \quark_if_recursion_tail_stop:N #1
          \exp_after:wN \__unicode_tmp:NNNNNNN
            \tex_number:D \__int_eval:w `#1 \exp_after:wN \__int_eval_end:
            \tex_number:D \__int_eval:w 100 + `#2 \__int_eval_end:
            #1 #2
          \__unicode_tmp:NN
        }
       \cs_set_protected:Npn \__unicode_tmp:NNNNNNN #1#2#3#4#5#6#7
         {
           \tl_const:cx { c__unicode_fold_  #1 _X_ #2 _ tl } { #6#7 }
           \tl_const:cn { c__unicode_lower_ #1 _X_ #2 _ tl } { #6#7 }
           \tl_const:cn { c__unicode_upper_ #4 _X_ #5 _ tl } { #7#6 }
         }
       \__unicode_tmp:NN
         AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz
        \q_recursion_tail ? \q_recursion_stop
    \group_end:
    \int_step_inline:nnnn { 0 } { 1 } { 9 }
      {
        \int_step_inline:nnnn { 0 } { 1 } { 9 }
          {
            \clist_map_inline:nn { fold , lower , upper }
              {
                \tl_if_exist:cF { c__unicode_ ####1 _ #1 _X_ ##1 _ tl }
                  { \tl_const:cn { c__unicode_ ####1 _ #1 _X_ ##1 _ tl } { } }
              }
          }
      }
    \tl_const:Nn \c__unicode_lower_exceptions_tl { }
    \tl_const:Nn \c__unicode_mixed_exceptions_tl { }
    \tl_const:Nn \c__unicode_upper_exceptions_tl { }
    \tl_const:Nn \c__unicode_std_sigma_tl   { }
    \tl_const:Nn \c__unicode_final_sigma_tl { }
    \tl_const:Nn \c__unicode_accents_lt_tl  { }
    \tl_const:Nn \c__unicode_dot_above_tl   { }
    \tl_const:Nn \c__unicode_dotless_i_tl   { I }
    \tl_const:Nn \c__unicode_dotted_I_tl    { i }
    \tl_const:Nn \c__unicode_i_ogonek_tl    { }
    \tl_const:Nn \c__unicode_I_ogonek_tl    { }
    \tex_endinput:D
  }
\tl_const:cn { c__unicode_lower_0_X_0_tl } { ÈèĬĭƐɛǴǵϨϩҰұԔԕḔḕṸṹỜờⒸⓒⰤⱔⲈⲉꙨꙩ }
\tl_const:cn { c__unicode_lower_0_X_1_tl } { ÉéƑƒჍⴭⒹⓓⰥⱕⳭⳮ }
\tl_const:cn { c__unicode_lower_0_X_2_tl } { ÊêĮįǶƕΆάϪϫҲҳԖԗḖḗṺṻỞởⒺⓔⰦⱖⲊⲋꙪꙫꜲꜳꞖꞗ }
\tl_const:cn { c__unicode_lower_0_X_3_tl } { ËëƓɠǷƿⒻⓕⰧⱗ }
\tl_const:cn { c__unicode_lower_0_X_4_tl } { ÌìİiƔɣǸǹΈέϬϭҴҵԘԙḘḙṼṽỠỡᾨᾠⒼⓖⰨⱘⲌⲍꙬꙭꜴꜵꞘꞙ }
\tl_const:cn { c__unicode_lower_0_X_5_tl } { ÍíΉήᾩᾡⒽⓗⰩⱙ }
\tl_const:cn { c__unicode_lower_0_X_6_tl } { Îî{Ĳ}{ĳ}ƖɩǺǻΊίϮϯҶҷԚԛḚḛṾṿỢợᾪᾢⒾⓘⰪⱚⲎⲏⳲⳳꜶꜷꞚꞛ }
\tl_const:cn { c__unicode_lower_0_X_7_tl } { ÏïƗɨᾫᾣⒿⓙⰫⱛ }
\tl_const:cn { c__unicode_lower_0_X_8_tl } { ÐðĴĵƘƙǼǽΌόҸҹԜԝḜḝẀẁỤụὈὀᾬᾤⓀⓚⰬⱜⲐⲑꜸꜹꞜꞝ }
\tl_const:cn { c__unicode_lower_0_X_9_tl } { ÑñὉὁᾭᾥⓁⓛⰭⱝ }
\tl_const:cn { c__unicode_lower_1_X_0_tl } { ÒòĶķǾǿΎύҺһԞԟḞḟẂẃỦủὊὂᾮᾦⓂⓜⰮⱞⲒⲓꜺꜻꞞꞟ }
\tl_const:cn { c__unicode_lower_1_X_1_tl } { ÓóΏώὋὃᾯᾧⓃⓝ }
\tl_const:cn { c__unicode_lower_1_X_2_tl } { ÔôƜɯȀȁϴθҼҽԠԡḠḡẄẅỨứὌὄⓄⓞⲔⲕꜼꜽꞠꞡ }
\tl_const:cn { c__unicode_lower_1_X_3_tl } { ÕõĹĺƝɲΑαὍὅⓅⓟＡａ }
\tl_const:cn { c__unicode_lower_1_X_4_tl } { ÖöȂȃΒβҾҿԢԣḢḣẆẇỪừⓆⓠⲖⲗꜾꜿꞢꞣＢｂ }
\tl_const:cn { c__unicode_lower_1_X_5_tl } { ĻļƟɵΓγϷϸⓇⓡＣｃ }
\tl_const:cn { c__unicode_lower_1_X_6_tl } { ØøƠơȄȅΔδӀӏԤԥḤḥẈẉỬửⓈⓢⲘⲙꝀꝁꞤꞥＤｄ }
\tl_const:cn { c__unicode_lower_1_X_7_tl } { ÙùĽľΕεϹϲӁӂⓉⓣＥｅ }
\tl_const:cn { c__unicode_lower_1_X_8_tl } { ÚúƢƣȆȇΖζϺϻԦԧḦḧẊẋỮữⓊⓤⲚⲛꝂꝃꞦꞧＦｆ }
\tl_const:cn { c__unicode_lower_1_X_9_tl } { ÛûĿŀΗηӃӄⓋⓥＧｇ }
\tl_const:cn { c__unicode_lower_2_X_0_tl } { ÜüƤƥȈȉΘθѠѡԨԩḨḩẌẍỰựᾸᾰⓌⓦⲜⲝꝄꝅꞨꞩＨｈ }
\tl_const:cn { c__unicode_lower_2_X_1_tl } { ÝýŁłΙιϽͻӅӆᾹᾱⓍⓧＩｉ }
\tl_const:cn { c__unicode_lower_2_X_2_tl } { ÞþƦʀȊȋΚκϾͼѢѣԪԫḪḫẎẏỲỳᾺὰⓎⓨⲞⲟꝆꝇꞪɦＪｊ }
\tl_const:cn { c__unicode_lower_2_X_3_tl } { ŃńƧƨΛλϿͽӇӈΆάⓏⓩꞫɜＫｋ }
\tl_const:cn { c__unicode_lower_2_X_4_tl } { ȌȍΜμЀѐѤѥԬԭḬḭẐẑỴỵᾼᾳⲠⲡꚀꚁꝈꝉꞬɡＬｌ }
\tl_const:cn { c__unicode_lower_2_X_5_tl } { ŅņƩʃΝνЁёӉӊὙὑꞭɬＭｍ }
\tl_const:cn { c__unicode_lower_2_X_6_tl } { ȎȏΞξЂђѦѧԮԯḮḯẒẓỶỷⲢⲣꚂꚃꝊꝋＮｎ }
\tl_const:cn { c__unicode_lower_2_X_7_tl } { ŇňΟοЃѓӋӌὛὓＯｏ }
\tl_const:cn { c__unicode_lower_2_X_8_tl } { ƬƭȐȑΠπЄєѨѩḰḱẔẕỸỹⲤⲥꚄꚅꝌꝍꞰʞＰｐ }
\tl_const:cn { c__unicode_lower_2_X_9_tl } { ΡρЅѕӍӎԱաὝὕꞱʇＱｑ }
\tl_const:cn { c__unicode_lower_3_X_0_tl } { ŊŋƮʈȒȓІіѪѫԲբḲḳỺỻⲦⲧꚆꚇꝎꝏＲｒ }
\tl_const:cn { c__unicode_lower_3_X_1_tl } { ƯưΣσЇїԳգὟὗＳｓ }
\tl_const:cn { c__unicode_lower_3_X_2_tl } { ŌōȔȕΤτЈјѬѭӐӑԴդḴḵỼỽⲨⲩꚈꚉꝐꝑＴｔ }
\tl_const:cn { c__unicode_lower_3_X_3_tl } { ƱʊΥυЉљԵեＵｕ }
\tl_const:cn { c__unicode_lower_3_X_4_tl } { ŎŏƲʋȖȗΦφЊњѮѯӒӓԶզḶḷỾỿⲪⲫꚊꚋꝒꝓＶｖ }
\tl_const:cn { c__unicode_lower_3_X_5_tl } { ƳƴΧχЋћԷէＷｗ }
\tl_const:cn { c__unicode_lower_3_X_6_tl } { ŐőȘșΨψЌќѰѱӔӕԸըḸḹῈὲⲬⲭꚌꚍꝔꝕＸｘ }
\tl_const:cn { c__unicode_lower_3_X_7_tl } { ƵƶΩωЍѝԹթΈέＹｙ }
\tl_const:cn { c__unicode_lower_3_X_8_tl } { ŒœȚțΪϊЎўѲѳӖӗԺժḺḻẞßῊὴⲮⲯꚎꚏꝖꝗＺｚ }
\tl_const:cn { c__unicode_lower_3_X_9_tl } { ƷʒΫϋЏџԻիΉή }
\tl_const:cn { c__unicode_lower_4_X_0_tl } { ŔŕƸƹȜȝАаѴѵӘәԼլḼḽẠạὨὠῌῃⲰⲱꚐꚑꝘꝙ𑢠𑣀 }
\tl_const:cn { c__unicode_lower_4_X_1_tl } { БбԽխὩὡ𑢡𑣁 }
\tl_const:cn { c__unicode_lower_4_X_2_tl } { ŖŗȞȟВвѶѷӚӛԾծḾḿẢảὪὢⲲⲳꚒꚓꝚꝛ𑢢𑣂 }
\tl_const:cn { c__unicode_lower_4_X_3_tl } { ГгԿկὫὣ𑢣𑣃 }
\tl_const:cn { c__unicode_lower_4_X_4_tl } { ŘřƼƽȠƞДдѸѹӜӝՀհṀṁẤấἈἀὬὤⅠⅰⲴⲵꚔꚕꝜꝝ𑢤𑣄 }
\tl_const:cn { c__unicode_lower_4_X_5_tl } { ЕеՁձἉἁὭὥ{Ⅱ}{ⅱ}𑢥𑣅 }
\tl_const:cn { c__unicode_lower_4_X_6_tl } { ŚśȢȣЖжѺѻӞӟՂղṂṃẦầἊἂὮὦ{Ⅲ}{ⅲ}ⲶⲷꚖꚗꝞꝟ𑢦𑣆 }
\tl_const:cn { c__unicode_lower_4_X_7_tl } { ЗзՃճἋἃὯὧ{Ⅳ}{ⅳ}𑢧𑣇 }
\tl_const:cn { c__unicode_lower_4_X_8_tl } { ŜŝȤȥИиѼѽӠӡՄմṄṅẨẩἌἄⅤⅴⲸⲹꚘꚙꝠꝡ𑢨𑣈 }
\tl_const:cn { c__unicode_lower_4_X_9_tl } { ЙйՅյἍἅ{Ⅵ}{ⅵ}𑢩𑣉 }
\tl_const:cn { c__unicode_lower_5_X_0_tl } { ŞşȦȧКкѾѿӢӣՆնṆṇẪẫἎἆ{Ⅶ}{ⅶ}ⲺⲻꚚꚛꝢꝣ𑢪𑣊 }
\tl_const:cn { c__unicode_lower_5_X_1_tl } { ЛлՇշἏἇ{Ⅷ}{ⅷ}𑢫𑣋 }
\tl_const:cn { c__unicode_lower_5_X_2_tl } { ŠšǄǆȨȩМмҀҁӤӥՈոṈṉẬậῘῐ{Ⅸ}{ⅸ}ⲼⲽꝤꝥ𑢬𑣌 }
\tl_const:cn { c__unicode_lower_5_X_3_tl } { ǅǆНнՉչῙῑⅩⅹ𑢭𑣍 }
\tl_const:cn { c__unicode_lower_5_X_4_tl } { ŢţȪȫОоӦӧՊպṊṋẮắῚὶⅪⅺⲾⲿꝦꝧ𑢮𑣎 }
\tl_const:cn { c__unicode_lower_5_X_5_tl } { ǇǉПпՋջΊίⅫⅻ𑢯𑣏 }
\tl_const:cn { c__unicode_lower_5_X_6_tl } { ĀāŤťǈǉȬȭРрӨөՌռႠⴀṌṍẰằⅬⅼⳀⳁꝨꝩ𑢰𑣐 }
\tl_const:cn { c__unicode_lower_5_X_7_tl } { СсՍսႡⴁⅭⅽ𑢱𑣑 }
\tl_const:cn { c__unicode_lower_5_X_8_tl } { ĂăŦŧǊǌȮȯТтӪӫՎվႢⴂṎṏẲẳⅮⅾⳂⳃꝪꝫ𑢲𑣒 }
\tl_const:cn { c__unicode_lower_5_X_9_tl } { ǋǌУуՏտႣⴃⅯⅿ𑢳𑣓 }
\tl_const:cn { c__unicode_lower_6_X_0_tl } { ĄąŨũȰȱФфӬӭՐրႤⴄṐṑẴẵἘἐⱠⱡⳄⳅꙀꙁꝬꝭ𐐀𐐨𑢴𑣔 }
\tl_const:cn { c__unicode_lower_6_X_1_tl } { ǍǎХхՑցႥⴅἙἑ𐐁𐐩𑢵𑣕 }
\tl_const:cn { c__unicode_lower_6_X_2_tl } { ĆćŪūȲȳЦцҊҋӮӯՒւႦⴆṒṓẶặἚἒⱢɫⳆⳇꙂꙃꝮꝯ𐐂𐐪𑢶𑣖 }
\tl_const:cn { c__unicode_lower_6_X_3_tl } { ǏǐЧчՓփႧⴇἛἓⱣᵽ𐐃𐐫𑢷𑣗 }
\tl_const:cn { c__unicode_lower_6_X_4_tl } { ĈĉŬŭШшҌҍӰӱՔքႨⴈṔṕẸẹἜἔⰀⰰⱤɽⳈⳉꙄꙅ𐐄𐐬𑢸𑣘 }
\tl_const:cn { c__unicode_lower_6_X_5_tl } { AaǑǒЩщՕօႩⴉἝἕⰁⰱ𐐅𐐭𑢹𑣙 }
\tl_const:cn { c__unicode_lower_6_X_6_tl } { BbĊċŮůЪъҎҏӲӳՖֆႪⴊṖṗẺẻⰂⰲⳊⳋꙆꙇ𐐆𐐮𑢺𑣚 }
\tl_const:cn { c__unicode_lower_6_X_7_tl } { CcǓǔЫыႫⴋⰃⰳⱧⱨ𐐇𐐯𑢻𑣛 }
\tl_const:cn { c__unicode_lower_6_X_8_tl } { DdČčŰűЬьҐґӴӵႬⴌṘṙẼẽῨῠⰄⰴⳌⳍꙈꙉ𐐈𐐰𑢼𑣜 }
\tl_const:cn { c__unicode_lower_6_X_9_tl } { EeǕǖЭэႭⴍῩῡⰅⰵⱩⱪ𐐉𐐱𑢽𑣝 }
\tl_const:cn { c__unicode_lower_7_X_0_tl } { FfĎďŲųȺⱥЮюҒғӶӷႮⴎṚṛẾếῪὺⰆⰶⳎⳏꙊꙋ𐐊𐐲𑢾𑣞 }
\tl_const:cn { c__unicode_lower_7_X_1_tl } { GgǗǘȻȼЯяႯⴏΎύⰇⰷⱫⱬ𐐋𐐳𑢿𑣟 }
\tl_const:cn { c__unicode_lower_7_X_2_tl } { HhĐđŴŵҔҕӸӹႰⴐṜṝỀềᾈᾀῬῥⰈⰸⳐⳑꙌꙍ𐐌𐐴 }
\tl_const:cn { c__unicode_lower_7_X_3_tl } { IiǙǚȽƚႱⴑᾉᾁⰉⰹⱭɑꝹꝺ𐐍𐐵 }
\tl_const:cn { c__unicode_lower_7_X_4_tl } { JjĒēŶŷȾⱦҖҗӺӻႲⴒṞṟỂểᾊᾂⰊⰺⱮɱⳒⳓꙎꙏ𐐎𐐶 }
\tl_const:cn { c__unicode_lower_7_X_5_tl } { KkǛǜϏϗႳⴓᾋᾃⰋⰻⱯɐꝻꝼ𐐏𐐷 }
\tl_const:cn { c__unicode_lower_7_X_6_tl } { LlĔĕŸÿҘҙӼӽႴⴔṠṡỄễἨἠᾌᾄⰌⰼⱰɒⳔⳕꙐꙑ𐐐𐐸 }
\tl_const:cn { c__unicode_lower_7_X_7_tl } { MmŹźɁɂႵⴕἩἡᾍᾅⰍⰽꝽᵹ𐐑𐐹 }
\tl_const:cn { c__unicode_lower_7_X_8_tl } { NnĖėǞǟҚқӾӿႶⴖṢṣỆệἪἢᾎᾆⰎⰾⱲⱳⳖⳗꙒꙓꝾꝿ𐐒𐐺 }
\tl_const:cn { c__unicode_lower_7_X_9_tl } { OoŻżɃƀႷⴗἫἣᾏᾇↃↄⰏⰿ𐐓𐐻 }
\tl_const:cn { c__unicode_lower_8_X_0_tl } { PpĘęǠǡɄʉͰͱҜҝԀԁႸⴘḀḁṤṥỈỉἬἤⰐⱀⳘⳙꙔꙕꞀꞁ𐐔𐐼 }
\tl_const:cn { c__unicode_lower_8_X_1_tl } { QqŽžɅʌႹⴙἭἥⰑⱁⱵⱶ𐐕𐐽 }
\tl_const:cn { c__unicode_lower_8_X_2_tl } { RrĚěǢǣɆɇͲͳҞҟԂԃႺⴚḂḃṦṧỊịἮἦⰒⱂⳚⳛꙖꙗꞂꞃ𐐖𐐾 }
\tl_const:cn { c__unicode_lower_8_X_3_tl } { SsႻⴛἯἧⰓⱃ𐐗𐐿 }
\tl_const:cn { c__unicode_lower_8_X_4_tl } { TtĜĝǤǥɈɉϘϙҠҡԄԅႼⴜḄḅṨṩỌọῸὸⰔⱄⳜⳝꙘꙙꞄꞅ𐐘𐑀 }
\tl_const:cn { c__unicode_lower_8_X_5_tl } { UuƁɓႽⴝΌόⰕⱅ𐐙𐑁 }
\tl_const:cn { c__unicode_lower_8_X_6_tl } { VvĞğƂƃǦǧɊɋͶͷϚϛҢңԆԇႾⴞḆḇṪṫỎỏῺὼΩωⰖⱆⳞⳟꙚꙛꜢꜣꞆꞇ𐐚𐑂 }
\tl_const:cn { c__unicode_lower_8_X_7_tl } { WwႿⴟΏώⰗⱇ𐐛𐑃 }
\tl_const:cn { c__unicode_lower_8_X_8_tl } { XxĠġƄƅǨǩɌɍϜϝҤҥԈԉჀⴠḈḉṬṭỐốᾘᾐῼῳⰘⱈⳠⳡꙜꙝꜤꜥ𐐜𐑄 }
\tl_const:cn { c__unicode_lower_8_X_9_tl } { YyჁⴡᾙᾑⰙⱉ𐐝𐑅 }
\tl_const:cn { c__unicode_lower_9_X_0_tl } { ZzĢģƆɔǪǫɎɏϞϟҦҧԊԋჂⴢḊḋṮṯỒồᾚᾒKkⰚⱊⱾȿⳢⳣꙞꙟꜦꜧ𐐞𐑆 }
\tl_const:cn { c__unicode_lower_9_X_1_tl } { ƇƈჃⴣᾛᾓÅåⰛⱋⱿɀꞋꞌ𐐟𐑇 }
\tl_const:cn { c__unicode_lower_9_X_2_tl } { ÀàĤĥǬǭϠϡҨҩԌԍჄⴤḌḍṰṱỔổἸἰᾜᾔⰜⱌⲀⲁꙠꙡꜨꜩ𐐠𐑈 }
\tl_const:cn { c__unicode_lower_9_X_3_tl } { ÁáƉɖჅⴥἹἱᾝᾕⰝⱍꞍɥ𐐡𐑉 }
\tl_const:cn { c__unicode_lower_9_X_4_tl } { ÂâĦħƊɗǮǯϢϣҪҫԎԏḎḏṲṳỖỗἺἲᾞᾖⰞⱎⲂⲃꙢꙣꜪꜫ𐐢𐑊 }
\tl_const:cn { c__unicode_lower_9_X_5_tl } { ÃãƋƌͿϳჇⴧἻἳᾟᾗⰟⱏ𐐣𐑋 }
\tl_const:cn { c__unicode_lower_9_X_6_tl } { ÄäĨĩϤϥҬҭԐԑḐḑṴṵỘộἼἴⰠⱐⲄⲅꙤꙥꜬꜭꞐꞑ𐐤𐑌 }
\tl_const:cn { c__unicode_lower_9_X_7_tl } { ÅåǱǳἽἵⰡⱑ𐐥𐑍 }
\tl_const:cn { c__unicode_lower_9_X_8_tl } { ÆæĪīƎǝǲǳϦϧҮүԒԓḒḓṶṷỚớἾἶℲⅎⒶⓐⰢⱒⲆⲇꙦꙧꜮꜯꞒꞓ𐐦𐑎 }
\tl_const:cn { c__unicode_lower_9_X_9_tl } { ÇçƏəἿἷⒷⓑⰣⱓⳫⳬ𐐧𐑏 }
\tl_const:cn { c__unicode_upper_0_X_0_tl } { dDьЬոՈὀὈᾤᾬⳬⳫ𐐨𐐀𑣜𑢼 }
\tl_const:cn { c__unicode_upper_0_X_1_tl } { eEĭĬǵǴəƏϩϨэЭұҰԕԔչՉḕḔṹṸờỜὁὉᾥᾭⲉⲈꙩꙨ𐐩𐐁𑣝𑢽 }
\tl_const:cn { c__unicode_upper_0_X_2_tl } { fFƒƑюЮպՊὂὊᾦᾮⳮⳭ𐐪𐐂𑣞𑢾 }
\tl_const:cn { c__unicode_upper_0_X_3_tl } { gGįĮɛƐϫϪяЯҳҲԗԖջՋḗḖṻṺởỞὃὋᾧᾯⲋⲊꙫꙪꜳꜲꞗꞖ𐐫𐐃𑣟𑢿 }
\tl_const:cn { c__unicode_upper_0_X_4_tl } { hHɜꞫѐЀռՌὄὌ𐐬𐐄 }
\tl_const:cn { c__unicode_upper_0_X_5_tl } { iIıIƕǶǹǸϭϬёЁҵҴԙԘսՍḙḘṽṼỡỠὅὍⲍⲌꙭꙬꜵꜴꞙꞘ𐐭𐐅 }
\tl_const:cn { c__unicode_upper_0_X_6_tl } { jJђЂվՎ𐐮𐐆 }
\tl_const:cn { c__unicode_upper_0_X_7_tl } { kK{ĳ}{Ĳ}ǻǺϯϮѓЃҷҶԛԚտՏḛḚṿṾợỢⲏⲎⳳⳲꜷꜶꞛꞚ𐐯𐐇 }
\tl_const:cn { c__unicode_upper_0_X_8_tl } { lLɠƓϰΚєЄրՐ𐐰𐐈 }
\tl_const:cn { c__unicode_upper_0_X_9_tl } { mMĵĴƙƘǽǼɡꞬϱΡѕЅҹҸԝԜցՑḝḜẁẀụỤⲑⲐꜹꜸꞝꞜ𐐱𐐉 }
\tl_const:cn { c__unicode_upper_1_X_0_tl } { nNƚȽϲϹіІւՒ𐐲𐐊 }
\tl_const:cn { c__unicode_upper_1_X_1_tl } { oOķĶǿǾɣƔϳͿїЇһҺԟԞփՓḟḞẃẂủỦⲓⲒꜻꜺꞟꞞ𐐳𐐋 }
\tl_const:cn { c__unicode_upper_1_X_2_tl } { pPјЈքՔᾰᾸⰰⰀ𐐴𐐌 }
\tl_const:cn { c__unicode_upper_1_X_3_tl } { qQȁȀɥꞍϵΕљЉҽҼԡԠօՕḡḠẅẄứỨᾱᾹⰱⰁⲕⲔꜽꜼꞡꞠ𐐵𐐍 }
\tl_const:cn { c__unicode_upper_1_X_4_tl } { rRĺĹƞȠɦꞪњЊֆՖⰲⰂ𐐶𐐎 }
\tl_const:cn { c__unicode_upper_1_X_5_tl } { sSȃȂћЋҿҾԣԢḣḢẇẆừỪᾳᾼⰳⰃⲗⲖꜿꜾꞣꞢ𐐷𐐏 }
\tl_const:cn { c__unicode_upper_1_X_6_tl } { tTļĻɨƗϸϷќЌⰴⰄ𐐸𐐐 }
\tl_const:cn { c__unicode_upper_1_X_7_tl } { uUơƠȅȄɩƖѝЍԥԤḥḤẉẈửỬὑὙⰵⰅⲙⲘꝁꝀꞥꞤ𐐹𐐑 }
\tl_const:cn { c__unicode_upper_1_X_8_tl } { vVľĽўЎӂӁⰶⰆ𐐺𐐒 }
\tl_const:cn { c__unicode_upper_1_X_9_tl } { wWƣƢȇȆɫⱢϻϺџЏԧԦḧḦẋẊữỮὓὛⰷⰇⲛⲚꝃꝂꞧꞦ𐐻𐐓 }
\tl_const:cn { c__unicode_upper_2_X_0_tl } { xX{ŀ}{Ŀ}ɬꞭӄӃⰸⰈⴀႠ𐐼𐐔 }
\tl_const:cn { c__unicode_upper_2_X_1_tl } { yYƥƤȉȈѡѠԩԨḩḨẍẌựỰὕὝⰹⰉⲝⲜⴁႡꝅꝄꞩꞨ𐐽𐐕 }
\tl_const:cn { c__unicode_upper_2_X_2_tl } { zZłŁӆӅⰺⰊⴂႢ𐐾𐐖 }
\tl_const:cn { c__unicode_upper_2_X_3_tl } { ȋȊɯƜѣѢԫԪḫḪẏẎỳỲὗὟⰻⰋⲟⲞⴃႣꝇꝆ𐐿𐐗 }
\tl_const:cn { c__unicode_upper_2_X_4_tl } { àÀńŃƨƧӈӇⓐⒶⰼⰌⴄႤ𐑀𐐘 }
\tl_const:cn { c__unicode_upper_2_X_5_tl } { áÁȍȌɱⱮѥѤԭԬḭḬẑẐỵỴⓑⒷⰽⰍⲡⲠⴅႥꚁꚀꝉꝈ𐑁𐐙 }
\tl_const:cn { c__unicode_upper_2_X_6_tl } { âÂņŅɲƝӊӉιΙⅎℲⓒⒸⰾⰎⴆႦ𐑂𐐚 }
\tl_const:cn { c__unicode_upper_2_X_7_tl } { ãÃȏȎѧѦԯԮḯḮẓẒỷỶⓓⒹⰿⰏⲣⲢⴇႧꚃꚂꝋꝊ𐑃𐐛 }
\tl_const:cn { c__unicode_upper_2_X_8_tl } { äÄňŇӌӋⓔⒺⱀⰐⴈႨ𐑄𐐜 }
\tl_const:cn { c__unicode_upper_2_X_9_tl } { åÅƭƬȑȐɵƟѩѨḱḰẕẔỹỸⓕⒻⱁⰑⲥⲤⴉႩꚅꚄꝍꝌ𐑅𐐝 }
\tl_const:cn { c__unicode_upper_3_X_0_tl } { æÆӎӍⓖⒼⱂⰒⴊႪ𐑆𐐞 }
\tl_const:cn { c__unicode_upper_3_X_1_tl } { çÇŋŊȓȒѫѪӏӀḳḲỻỺῃῌⓗⒽⱃⰓⲧⲦⴋႫꚇꚆꝏꝎ𐑇𐐟 }
\tl_const:cn { c__unicode_upper_3_X_2_tl } { èÈưƯὠὨⓘⒾⱄⰔⴌႬ𐑈𐐠 }
\tl_const:cn { c__unicode_upper_3_X_3_tl } { éÉōŌȕȔѭѬӑӐḵḴỽỼὡὩⓙⒿⱅⰕⲩⲨⴍႭꚉꚈꝑꝐ𐑉𐐡 }
\tl_const:cn { c__unicode_upper_3_X_4_tl } { êÊὢὪⓚⓀⱆⰖⴎႮ𐑊𐐢 }
\tl_const:cn { c__unicode_upper_3_X_5_tl } { ëËŏŎȗȖѯѮӓӒḷḶẛṠỿỾὣὫⓛⓁⱇⰗⲫⲪⴏႯꚋꚊꝓꝒ𐑋𐐣 }
\tl_const:cn { c__unicode_upper_3_X_6_tl } { ìÌƴƳἀἈὤὬⓜⓂⱈⰘⴐႰ𐑌𐐤 }
\tl_const:cn { c__unicode_upper_3_X_7_tl } { íÍőŐșȘɽⱤͅΙѱѰӕӔḹḸἁἉὥὭⓝⓃⱉⰙⲭⲬⴑႱꚍꚌꝕꝔ𐑍𐐥 }
\tl_const:cn { c__unicode_upper_3_X_8_tl } { îÎƶƵἂἊὦὮⓞⓄⱊⰚⴒႲ𐑎𐐦 }
\tl_const:cn { c__unicode_upper_3_X_9_tl } { ïÏœŒțȚѳѲӗӖḻḺἃἋὧὯⓟⓅⱋⰛⲯⲮⴓႳꚏꚎꝗꝖ𐑏𐐧 }
\tl_const:cn { c__unicode_upper_4_X_0_tl } { ðÐʀƦάΆἄἌⓠⓆⱌⰜⴔႴ }
\tl_const:cn { c__unicode_upper_4_X_1_tl } { ñÑŕŔƹƸȝȜέΈѵѴәӘḽḼạẠἅἍⓡⓇⱍⰝⲱⲰⴕႵꚑꚐꝙꝘ }
\tl_const:cn { c__unicode_upper_4_X_2_tl } { òÒήΉἆἎⓢⓈⱎⰞⴖႶ }
\tl_const:cn { c__unicode_upper_4_X_3_tl } { óÓŗŖȟȞʃƩίΊѷѶӛӚḿḾảẢἇἏⓣⓉⱏⰟⲳⲲⴗႷꚓꚒꝛꝚ }
\tl_const:cn { c__unicode_upper_4_X_4_tl } { ôÔῐῘⓤⓊⱐⰠⴘႸ }
\tl_const:cn { c__unicode_upper_4_X_5_tl } { õÕřŘƽƼαΑѹѸӝӜᵹꝽṁṀấẤῑῙⓥⓋⱑⰡⲵⲴⴙႹꚕꚔꝝꝜａＡ }
\tl_const:cn { c__unicode_upper_4_X_6_tl } { öÖβΒⓦⓌⱒⰢⴚႺｂＢ }
\tl_const:cn { c__unicode_upper_4_X_7_tl } { śŚƿǷȣȢʇꞱγΓѻѺӟӞṃṂầẦⓧⓍⱓⰣⲷⲶⴛႻꚗꚖꝟꝞｃＣ }
\tl_const:cn { c__unicode_upper_4_X_8_tl } { øØʈƮδΔὰᾺⓨⓎⱔⰤⴜႼｄＤ }
\tl_const:cn { c__unicode_upper_4_X_9_tl } { ùÙŝŜȥȤʉɄεΕѽѼӡӠᵽⱣṅṄẩẨάΆⓩⓏⱕⰥⲹⲸⴝႽꚙꚘꝡꝠｅＥ }
\tl_const:cn { c__unicode_upper_5_X_0_tl } { úÚʊƱζΖὲῈⱖⰦⴞႾｆＦ }
\tl_const:cn { c__unicode_upper_5_X_1_tl } { ûÛşŞȧȦʋƲηΗѿѾӣӢṇṆẫẪέΈⱗⰧⲻⲺⴟႿꚛꚚꝣꝢｇＧ }
\tl_const:cn { c__unicode_upper_5_X_2_tl } { üÜʌɅθΘἐἘὴῊⱘⰨⴠჀｈＨ }
\tl_const:cn { c__unicode_upper_5_X_3_tl } { ýÝšŠǅǄȩȨιΙҁҀӥӤṉṈậẬἑἙήΉⱙⰩⲽⲼⴡჁꝥꝤｉＩ }
\tl_const:cn { c__unicode_upper_5_X_4_tl } { þÞǆǄκΚἒἚὶῚⱚⰪⴢჂｊＪ }
\tl_const:cn { c__unicode_upper_5_X_5_tl } { ÿŸţŢȫȪλΛӧӦṋṊắẮἓἛίΊⱛⰫⲿⲾⴣჃꝧꝦｋＫ }
\tl_const:cn { c__unicode_upper_5_X_6_tl } { ǈǇμΜἔἜὸῸⱜⰬⴤჄｌＬ }
\tl_const:cn { c__unicode_upper_5_X_7_tl } { āĀťŤǉǇȭȬνΝөӨṍṌằẰἕἝόΌⱝⰭⳁⳀⴥჅꝩꝨｍＭ }
\tl_const:cn { c__unicode_upper_5_X_8_tl } { ʒƷξΞὺῪⱞⰮｎＮ }
\tl_const:cn { c__unicode_upper_5_X_9_tl } { ăĂŧŦǋǊȯȮοΟӫӪṏṎẳẲύΎⳃⳂⴧჇꝫꝪｏＯ }
\tl_const:cn { c__unicode_upper_6_X_0_tl } { ǌǊπΠὼῺῠῨⅰⅠｐＰ }
\tl_const:cn { c__unicode_upper_6_X_1_tl } { ąĄũŨȱȰρΡӭӬṑṐẵẴώΏῡῩ{ⅱ}{Ⅱ}ⱡⱠⳅⳄꙁꙀꝭꝬｑＱ }
\tl_const:cn { c__unicode_upper_6_X_2_tl } { ǎǍςΣ{ⅲ}{Ⅲ}ｒＲ }
\tl_const:cn { c__unicode_upper_6_X_3_tl } { ćĆūŪȳȲσΣҋҊӯӮṓṒặẶ{ⅳ}{Ⅳ}ⳇⳆꙃꙂꝯꝮｓＳ }
\tl_const:cn { c__unicode_upper_6_X_4_tl } { ǐǏτΤᾀᾈⅴⅤｔＴ }
\tl_const:cn { c__unicode_upper_6_X_5_tl } { ĉĈŭŬυΥҍҌӱӰṕṔẹẸᾁᾉῥῬ{ⅵ}{Ⅵ}ⱥȺⳉⳈⴭჍꙅꙄｕＵ }
\tl_const:cn { c__unicode_upper_6_X_6_tl } { ǒǑφΦᾂᾊ{ⅶ}{Ⅶ}ⱦȾｖＶ }
\tl_const:cn { c__unicode_upper_6_X_7_tl } { ċĊůŮχΧҏҎӳӲṗṖẻẺᾃᾋ{ⅷ}{Ⅷ}ⳋⳊꙇꙆｗＷ }
\tl_const:cn { c__unicode_upper_6_X_8_tl } { ǔǓψΨἠἨᾄᾌ{ⅸ}{Ⅸ}ⱨⱧｘＸ }
\tl_const:cn { c__unicode_upper_6_X_9_tl } { čČűŰωΩґҐӵӴṙṘẽẼἡἩᾅᾍⅹⅩⳍⳌꙉꙈｙＹ }
\tl_const:cn { c__unicode_upper_7_X_0_tl } { ǖǕʞꞰϊΪἢἪᾆᾎⅺⅪⱪⱩｚＺ }
\tl_const:cn { c__unicode_upper_7_X_1_tl } { ďĎųŲϋΫғҒӷӶṛṚếẾἣἫᾇᾏⅻⅫⳏⳎꙋꙊ }
\tl_const:cn { c__unicode_upper_7_X_2_tl } { ǘǗȼȻόΌаАἤἬⅼⅬⱬⱫ𑣀𑢠 }
\tl_const:cn { c__unicode_upper_7_X_3_tl } { đĐŵŴύΎбБҕҔӹӸṝṜềỀἥἭⅽⅭⳑⳐꙍꙌ𑣁𑢡 }
\tl_const:cn { c__unicode_upper_7_X_4_tl } { ǚǙώΏвВἦἮⅾⅮꝺꝹ𑣂𑢢 }
\tl_const:cn { c__unicode_upper_7_X_5_tl } { ēĒŷŶȿⱾгГҗҖӻӺṟṞểỂἧἯⅿⅯⳓⳒꙏꙎ𑣃𑢣 }
\tl_const:cn { c__unicode_upper_7_X_6_tl } { ǜǛɀⱿϐΒдДꝼꝻ𑣄𑢤 }
\tl_const:cn { c__unicode_upper_7_X_7_tl } { ĕĔǝƎϑΘеЕҙҘӽӼաԱṡṠễỄⳕⳔꙑꙐ𑣅𑢥 }
\tl_const:cn { c__unicode_upper_7_X_8_tl } { źŹɂɁжЖբԲ𑣆𑢦 }
\tl_const:cn { c__unicode_upper_7_X_9_tl } { ėĖǟǞзЗқҚӿӾգԳṣṢệỆῳῼⱳⱲⳗⳖꙓꙒꝿꝾ𑣇𑢧 }
\tl_const:cn { c__unicode_upper_8_X_0_tl } { żŻиИդԴᾐᾘↄↃ𑣈𑢨 }
\tl_const:cn { c__unicode_upper_8_X_1_tl } { µΜęĘǡǠͱͰϕΦйЙҝҜԁԀեԵḁḀṥṤỉỈᾑᾙⳙⳘꙕꙔꞁꞀ𑣉𑢩 }
\tl_const:cn { c__unicode_upper_8_X_2_tl } { žŽϖΠкКզԶᾒᾚⱶⱵ𑣊𑢪 }
\tl_const:cn { c__unicode_upper_8_X_3_tl } { ěĚſSǣǢɇɆͳͲϗϏлЛҟҞԃԂէԷḃḂṧṦịỊᾓᾛⳛⳚꙗꙖꞃꞂ𑣋𑢫 }
\tl_const:cn { c__unicode_upper_8_X_4_tl } { ƀɃмМըԸἰἸᾔᾜ𑣌𑢬 }
\tl_const:cn { c__unicode_upper_8_X_5_tl } { ĝĜǥǤɉɈϙϘнНҡҠԅԄթԹḅḄṩṨọỌἱἹᾕᾝⳝⳜꙙꙘꞅꞄ𑣍𑢭 }
\tl_const:cn { c__unicode_upper_8_X_6_tl } { оОժԺἲἺᾖᾞ𑣎𑢮 }
\tl_const:cn { c__unicode_upper_8_X_7_tl } { ğĞƃƂǧǦɋɊͷͶϛϚпПңҢԇԆիԻḇḆṫṪỏỎἳἻᾗᾟⳟⳞꙛꙚꜣꜢꞇꞆ𑣏𑢯 }
\tl_const:cn { c__unicode_upper_8_X_8_tl } { рРլԼἴἼ𑣐𑢰 }
\tl_const:cn { c__unicode_upper_8_X_9_tl } { ġĠƅƄǩǨɍɌϝϜсСҥҤԉԈխԽḉḈṭṬốỐἵἽⳡⳠꙝꙜꜥꜤ𑣑𑢱 }
\tl_const:cn { c__unicode_upper_9_X_0_tl } { тТծԾἶἾ𑣒𑢲 }
\tl_const:cn { c__unicode_upper_9_X_1_tl } { ģĢǫǪɏɎͻϽϟϞуУҧҦԋԊկԿḋḊṯṮồỒἷἿⳣⳢꙟꙞꜧꜦ𑣓𑢳 }
\tl_const:cn { c__unicode_upper_9_X_2_tl } { ƈƇɐⱯͼϾфФհՀꞌꞋ𑣔𑢴 }
\tl_const:cn { c__unicode_upper_9_X_3_tl } { ĥĤǭǬɑⱭͽϿϡϠхХҩҨԍԌձՁḍḌṱṰổỔⲁⲀꙡꙠꜩꜨ𑣕𑢵 }
\tl_const:cn { c__unicode_upper_9_X_4_tl } { ɒⱰцЦղՂ𑣖𑢶 }
\tl_const:cn { c__unicode_upper_9_X_5_tl } { ħĦǯǮɓƁϣϢчЧҫҪԏԎճՃḏḎṳṲỗỖⲃⲂꙣꙢꜫꜪ𑣗𑢷 }
\tl_const:cn { c__unicode_upper_9_X_6_tl } { ƌƋɔƆшШմՄᾠᾨ𑣘𑢸 }
\tl_const:cn { c__unicode_upper_9_X_7_tl } { aAĩĨϥϤщЩҭҬԑԐյՅḑḐṵṴộỘᾡᾩⲅⲄꙥꙤꜭꜬꞑꞐ𑣙𑢹 }
\tl_const:cn { c__unicode_upper_9_X_8_tl } { bBǲǱɖƉъЪնՆᾢᾪ𑣚𑢺 }
\tl_const:cn { c__unicode_upper_9_X_9_tl } { cCīĪǳǱɗƊϧϦыЫүҮԓԒշՇḓḒṷṶớỚᾣᾫⲇⲆꙧꙦꜯꜮꞓꞒ𑣛𑢻 }
\tl_const:Nn \c__unicode_upper_exceptions_tl {ß{SS}{ﬀ}{FF}{ﬁ}{FI}{ﬂ}{FL}{ﬃ}{FFI}{ﬄ}{FFL}{ﬅ}{ST}{ﬆ}{ST}{և}{ԵՒ}{ﬓ}{ՄՆ}{ﬔ}{ՄԵ}{ﬕ}{ՄԻ}{ﬖ}{ՎՆ}{ﬗ}{ՄԽ}{ŉ}{ʼN}ΐ{Ϊ́}ΰ{Ϋ́}ǰ{J̌}ẖ{H̱}ẗ{T̈}ẘ{W̊}ẙ{Y̊}{ẚ}{Aʾ}ὐ{Υ̓}ὒ{Υ̓̀}ὔ{Υ̓́}ὖ{Υ̓͂}ᾶ{Α͂}ῆ{Η͂}ῒ{Ϊ̀}ΐ{Ϊ́}ῖ{Ι͂}ῗ{Ϊ͂}ῢ{Ϋ̀}ΰ{Ϋ́}ῤ{Ρ̓}ῦ{Υ͂}ῧ{Ϋ͂}ῶ{Ω͂}ᾀ{ἈΙ}ᾁ{ἉΙ}ᾂ{ἊΙ}ᾃ{ἋΙ}ᾄ{ἌΙ}ᾅ{ἍΙ}ᾆ{ἎΙ}ᾇ{ἏΙ}ᾈ{ἈΙ}ᾉ{ἉΙ}ᾊ{ἊΙ}ᾋ{ἋΙ}ᾌ{ἌΙ}ᾍ{ἍΙ}ᾎ{ἎΙ}ᾏ{ἏΙ}ᾐ{ἨΙ}ᾑ{ἩΙ}ᾒ{ἪΙ}ᾓ{ἫΙ}ᾔ{ἬΙ}ᾕ{ἭΙ}ᾖ{ἮΙ}ᾗ{ἯΙ}ᾘ{ἨΙ}ᾙ{ἩΙ}ᾚ{ἪΙ}ᾛ{ἫΙ}ᾜ{ἬΙ}ᾝ{ἭΙ}ᾞ{ἮΙ}ᾟ{ἯΙ}ᾠ{ὨΙ}ᾡ{ὩΙ}ᾢ{ὪΙ}ᾣ{ὫΙ}ᾤ{ὬΙ}ᾥ{ὭΙ}ᾦ{ὮΙ}ᾧ{ὯΙ}ᾨ{ὨΙ}ᾩ{ὩΙ}ᾪ{ὪΙ}ᾫ{ὫΙ}ᾬ{ὬΙ}ᾭ{ὭΙ}ᾮ{ὮΙ}ᾯ{ὯΙ}ᾳ{ΑΙ}ᾼ{ΑΙ}ῃ{ΗΙ}ῌ{ΗΙ}ῳ{ΩΙ}ῼ{ΩΙ}ᾲ{ᾺΙ}ᾴ{ΆΙ}ῂ{ῊΙ}ῄ{ΉΙ}ῲ{ῺΙ}ῴ{ΏΙ}ᾷ{Α͂Ι}ῇ{Η͂Ι}ῷ{Ω͂Ι}}
\tl_const:Nn \c__unicode_lower_exceptions_tl {İ{i̇}}
\tl_const:Nn \c__unicode_mixed_exceptions_tl {ǅǅǆǅǈǈǉǈǋǋǌǋǲǲǳǲß{Ss}{ﬀ}{Ff}{ﬁ}{Fi}{ﬂ}{Fl}{ﬃ}{Ffi}{ﬄ}{Ffl}{ﬅ}{St}{ﬆ}{St}{և}{Եւ}{ﬓ}{Մն}{ﬔ}{Մե}{ﬕ}{Մի}{ﬖ}{Վն}{ﬗ}{Մխ}ᾲ{Ὰͅ}ᾴ{Άͅ}ῂ{Ὴͅ}ῄ{Ήͅ}ῲ{Ὼͅ}ῴ{Ώͅ}ᾷ{ᾼ͂}ῇ{ῌ͂}ῷ{ῼ͂}}
\tl_const:Nn \c__unicode_std_sigma_tl { σ }
\tl_const:Nn \c__unicode_final_sigma_tl { ς }
\tl_const:Nn \c__unicode_dotless_i_tl { ı }
\tl_const:Nn \c__unicode_dot_above_tl { ̇ }
\tl_const:Nn \c__unicode_dotted_I_tl { İ }
\tl_const:Nn \c__unicode_i_ogonek_tl { į }
\tl_const:Nn \c__unicode_I_ogonek_tl { Į }
\tl_const:Nn \c__unicode_accents_lt_tl {Ì{i̇̀}Í{i̇́}Ĩ{i̇̃}}
\tl_const:cn { c__unicode_fold_0_X_0_tl } { ÈèĬĭƐɛǴǵϨϩҰұԔԕḔḕṸṹỜờᾤ{ὤι}ⒸⓒⰤⱔⲈⲉꙨꙩ }
\tl_const:cn { c__unicode_fold_0_X_1_tl } { ÉéƑƒჍⴭᾥ{ὥι}ⒹⓓⰥⱕⳭⳮ }
\tl_const:cn { c__unicode_fold_0_X_2_tl } { ÊêĮįǶƕΆάϪϫҲҳԖԗḖḗṺṻỞởᾦ{ὦι}ⒺⓔⰦⱖⲊⲋꙪꙫꜲꜳꞖꞗ }
\tl_const:cn { c__unicode_fold_0_X_3_tl } { ËëƓɠǷƿᾧ{ὧι}ⒻⓕⰧⱗ }
\tl_const:cn { c__unicode_fold_0_X_4_tl } { Ììİ{i̇}ƔɣǸǹΈέϬϭҴҵԘԙḘḙṼṽỠỡᾨ{ὠι}ⒼⓖⰨⱘⲌⲍꙬꙭꜴꜵꞘꞙ }
\tl_const:cn { c__unicode_fold_0_X_5_tl } { ÍíΉήᾩ{ὡι}ⒽⓗⰩⱙ }
\tl_const:cn { c__unicode_fold_0_X_6_tl } { Îî{Ĳ}{ĳ}ƖɩǺǻΊίϮϯҶҷԚԛḚḛṾṿỢợᾪ{ὢι}ⒾⓘⰪⱚⲎⲏⳲⳳꜶꜷꞚꞛ }
\tl_const:cn { c__unicode_fold_0_X_7_tl } { ÏïƗɨᾫ{ὣι}ⒿⓙⰫⱛ }
\tl_const:cn { c__unicode_fold_0_X_8_tl } { ÐðĴĵƘƙǼǽΌόϰκҸҹԜԝḜḝẀẁỤụὈὀᾬ{ὤι}ⓀⓚⰬⱜⲐⲑꜸꜹꞜꞝ }
\tl_const:cn { c__unicode_fold_0_X_9_tl } { ÑñϱρὉὁᾭ{ὥι}ⓁⓛⰭⱝ }
\tl_const:cn { c__unicode_fold_1_X_0_tl } { ÒòĶķǾǿΎύҺһԞԟḞḟẂẃỦủὊὂᾮ{ὦι}ⓂⓜⰮⱞⲒⲓꜺꜻꞞꞟ }
\tl_const:cn { c__unicode_fold_1_X_1_tl } { ÓóΏώὋὃᾯ{ὧι}Ⓝⓝ }
\tl_const:cn { c__unicode_fold_1_X_2_tl } { ÔôƜɯȀȁΐ{ΐ}ϴθҼҽԠԡḠḡẄẅỨứὌὄⓄⓞⲔⲕꜼꜽꞠꞡ }
\tl_const:cn { c__unicode_fold_1_X_3_tl } { ÕõĹĺƝɲΑαϵεὍὅⓅⓟＡａ }
\tl_const:cn { c__unicode_fold_1_X_4_tl } { ÖöȂȃΒβҾҿԢԣḢḣẆẇỪừᾲ{ὰι}ⓆⓠⲖⲗꜾꜿꞢꞣＢｂ }
\tl_const:cn { c__unicode_fold_1_X_5_tl } { ĻļƟɵΓγϷϸ{և}{եւ}ᾳ{αι}ⓇⓡＣｃ }
\tl_const:cn { c__unicode_fold_1_X_6_tl } { ØøƠơȄȅΔδӀӏԤԥḤḥẈẉỬửὐ{ὐ}ᾴ{άι}ⓈⓢⲘⲙꝀꝁꞤꞥＤｄ }
\tl_const:cn { c__unicode_fold_1_X_7_tl } { ÙùĽľΕεϹϲӁӂⓉⓣＥｅ }
\tl_const:cn { c__unicode_fold_1_X_8_tl } { ÚúƢƣȆȇΖζϺϻԦԧḦḧẊẋỮữὒ{ὒ}ᾶ{ᾶ}ⓊⓤⲚⲛꝂꝃꞦꞧＦｆ }
\tl_const:cn { c__unicode_fold_1_X_9_tl } { Ûû{Ŀ}{ŀ}ΗηӃӄᾷ{ᾶι}ⓋⓥＧｇ }
\tl_const:cn { c__unicode_fold_2_X_0_tl } { ÜüƤƥȈȉΘθѠѡԨԩḨḩẌẍỰựὔ{ὔ}ᾸᾰⓌⓦⲜⲝꝄꝅꞨꞩＨｈ }
\tl_const:cn { c__unicode_fold_2_X_1_tl } { ÝýŁłΙιϽͻӅӆᾹᾱⓍⓧＩｉ }
\tl_const:cn { c__unicode_fold_2_X_2_tl } { ÞþƦʀȊȋΚκϾͼѢѣԪԫḪḫẎẏỲỳὖ{ὖ}ᾺὰⓎⓨⲞⲟꝆꝇꞪɦＪｊ }
\tl_const:cn { c__unicode_fold_2_X_3_tl } { ß{ss}ŃńƧƨΛλϿͽӇӈΆάⓏⓩꞫɜＫｋ }
\tl_const:cn { c__unicode_fold_2_X_4_tl } { ȌȍΜμЀѐѤѥԬԭḬḭẐẑỴỵᾼ{αι}ⲠⲡꚀꚁꝈꝉꞬɡＬｌ }
\tl_const:cn { c__unicode_fold_2_X_5_tl } { ŅņƩʃΝνЁёӉӊὙὑꞭɬＭｍ }
\tl_const:cn { c__unicode_fold_2_X_6_tl } { ȎȏΞξЂђѦѧԮԯḮḯẒẓỶỷιιⲢⲣꚂꚃꝊꝋＮｎ }
\tl_const:cn { c__unicode_fold_2_X_7_tl } { ŇňΟοЃѓӋӌὛὓＯｏ }
\tl_const:cn { c__unicode_fold_2_X_8_tl } { ƬƭȐȑΠπЄєѨѩḰḱẔẕỸỹⲤⲥꚄꚅꝌꝍꞰʞＰｐ }
\tl_const:cn { c__unicode_fold_2_X_9_tl } { {ŉ}{ʼn}ΡρЅѕӍӎԱաὝὕꞱʇＱｑ }
\tl_const:cn { c__unicode_fold_3_X_0_tl } { ŊŋƮʈȒȓІіѪѫԲբḲḳẖ{ẖ}Ỻỻῂ{ὴι}ⲦⲧꚆꚇꝎꝏＲｒ }
\tl_const:cn { c__unicode_fold_3_X_1_tl } { ƯưΣσЇїԳգẗ{ẗ}Ὗὗῃ{ηι}Ｓｓ }
\tl_const:cn { c__unicode_fold_3_X_2_tl } { ŌōȔȕΤτЈјѬѭӐӑԴդḴḵẘ{ẘ}Ỽỽῄ{ήι}ⲨⲩꚈꚉꝐꝑＴｔ }
\tl_const:cn { c__unicode_fold_3_X_3_tl } { ƱʊΥυЉљԵեẙ{ẙ}Ｕｕ }
\tl_const:cn { c__unicode_fold_3_X_4_tl } { ŎŏƲʋȖȗΦφЊњѮѯӒӓԶզḶḷ{ẚ}{aʾ}Ỿỿῆ{ῆ}ⲪⲫꚊꚋꝒꝓＶｖ }
\tl_const:cn { c__unicode_fold_3_X_5_tl } { ƳƴΧχЋћԷէẛṡῇ{ῆι}Ｗｗ }
\tl_const:cn { c__unicode_fold_3_X_6_tl } { ŐőȘșΨψЌќѰѱӔӕԸըḸḹῈὲⲬⲭꚌꚍꝔꝕＸｘ }
\tl_const:cn { c__unicode_fold_3_X_7_tl } { ƵƶͅιΩωЍѝԹթΈέＹｙ }
\tl_const:cn { c__unicode_fold_3_X_8_tl } { ŒœȚțΪϊЎўѲѳӖӗԺժḺḻẞ{ss}ῊὴⲮⲯꚎꚏꝖꝗＺｚ }
\tl_const:cn { c__unicode_fold_3_X_9_tl } { ƷʒΫϋЏџԻիΉή }
\tl_const:cn { c__unicode_fold_4_X_0_tl } { ŔŕƸƹȜȝАаѴѵӘәԼլḼḽẠạὨὠῌ{ηι}ⲰⲱꚐꚑꝘꝙ𑢠𑣀 }
\tl_const:cn { c__unicode_fold_4_X_1_tl } { БбԽխὩὡ𑢡𑣁 }
\tl_const:cn { c__unicode_fold_4_X_2_tl } { ŖŗȞȟВвѶѷӚӛԾծḾḿẢảὪὢⲲⲳꚒꚓꝚꝛ𑢢𑣂 }
\tl_const:cn { c__unicode_fold_4_X_3_tl } { ГгԿկὫὣ𑢣𑣃 }
\tl_const:cn { c__unicode_fold_4_X_4_tl } { ŘřƼƽȠƞΰ{ΰ}ДдѸѹӜӝՀհṀṁẤấἈἀὬὤⅠⅰⲴⲵꚔꚕꝜꝝ𑢤𑣄 }
\tl_const:cn { c__unicode_fold_4_X_5_tl } { ЕеՁձἉἁὭὥ{Ⅱ}{ⅱ}𑢥𑣅 }
\tl_const:cn { c__unicode_fold_4_X_6_tl } { ŚśȢȣЖжѺѻӞӟՂղṂṃẦầἊἂὮὦῒ{ῒ}{Ⅲ}{ⅲ}ⲶⲷꚖꚗꝞꝟ𑢦𑣆 }
\tl_const:cn { c__unicode_fold_4_X_7_tl } { ЗзՃճἋἃὯὧΐ{ΐ}{Ⅳ}{ⅳ}𑢧𑣇 }
\tl_const:cn { c__unicode_fold_4_X_8_tl } { ŜŝȤȥИиѼѽӠӡՄմṄṅẨẩἌἄⅤⅴⲸⲹꚘꚙꝠꝡ𑢨𑣈 }
\tl_const:cn { c__unicode_fold_4_X_9_tl } { ЙйՅյἍἅ{Ⅵ}{ⅵ}𑢩𑣉 }
\tl_const:cn { c__unicode_fold_5_X_0_tl } { ŞşȦȧКкѾѿӢӣՆնṆṇẪẫἎἆῖ{ῖ}{Ⅶ}{ⅶ}ⲺⲻꚚꚛꝢꝣ𑢪𑣊 }
\tl_const:cn { c__unicode_fold_5_X_1_tl } { ЛлՇշἏἇῗ{ῗ}{Ⅷ}{ⅷ}𑢫𑣋 }
\tl_const:cn { c__unicode_fold_5_X_2_tl } { Šš{Ǆ}{ǆ}ȨȩМмҀҁӤӥՈոṈṉẬậῘῐ{Ⅸ}{ⅸ}ⲼⲽꝤꝥ𑢬𑣌 }
\tl_const:cn { c__unicode_fold_5_X_3_tl } { {ǅ}{ǆ}НнՉչῙῑⅩⅹ𑢭𑣍 }
\tl_const:cn { c__unicode_fold_5_X_4_tl } { ŢţȪȫОоӦӧՊպṊṋẮắῚὶ{Ⅺ}{ⅺ}ⲾⲿꝦꝧ𑢮𑣎 }
\tl_const:cn { c__unicode_fold_5_X_5_tl } { {Ǉ}{ǉ}ПпՋջΊί{Ⅻ}{ⅻ}𑢯𑣏 }
\tl_const:cn { c__unicode_fold_5_X_6_tl } { ĀāŤť{ǈ}{ǉ}ȬȭРрӨөՌռႠⴀṌṍẰằⅬⅼⳀⳁꝨꝩ{ﬀ}{ff}𑢰𑣐 }
\tl_const:cn { c__unicode_fold_5_X_7_tl } { СсՍսႡⴁⅭⅽ{ﬁ}{fi}𑢱𑣑 }
\tl_const:cn { c__unicode_fold_5_X_8_tl } { ĂăŦŧ{Ǌ}{ǌ}ȮȯТтӪӫՎվႢⴂṎṏẲẳⅮⅾⳂⳃꝪꝫ{ﬂ}{fl}𑢲𑣒 }
\tl_const:cn { c__unicode_fold_5_X_9_tl } { {ǋ}{ǌ}УуՏտႣⴃⅯⅿ{ﬃ}{ffi}𑢳𑣓 }
\tl_const:cn { c__unicode_fold_6_X_0_tl } { ĄąŨũȰȱФфӬӭՐրႤⴄṐṑẴẵἘἐⱠⱡⳄⳅꙀꙁꝬꝭ{ﬄ}{ffl}𐐀𐐨𑢴𑣔 }
\tl_const:cn { c__unicode_fold_6_X_1_tl } { ǍǎХхՑցႥⴅἙἑ{ﬅ}{st}𐐁𐐩𑢵𑣕 }
\tl_const:cn { c__unicode_fold_6_X_2_tl } { ĆćŪūȲȳςσЦцҊҋӮӯՒւႦⴆṒṓẶặἚἒῢ{ῢ}ⱢɫⳆⳇꙂꙃꝮꝯ{ﬆ}{st}𐐂𐐪𑢶𑣖 }
\tl_const:cn { c__unicode_fold_6_X_3_tl } { ǏǐЧчՓփႧⴇἛἓΰ{ΰ}Ᵽᵽ𐐃𐐫𑢷𑣗 }
\tl_const:cn { c__unicode_fold_6_X_4_tl } { ĈĉŬŭШшҌҍӰӱՔքႨⴈṔṕẸẹἜἔᾀ{ἀι}ῤ{ῤ}ⰀⰰⱤɽⳈⳉꙄꙅ𐐄𐐬𑢸𑣘 }
\tl_const:cn { c__unicode_fold_6_X_5_tl } { AaǑǒЩщՕօႩⴉἝἕᾁ{ἁι}Ⰱⰱ𐐅𐐭𑢹𑣙 }
\tl_const:cn { c__unicode_fold_6_X_6_tl } { BbĊċŮůЪъҎҏӲӳՖֆႪⴊṖṗẺẻᾂ{ἂι}ῦ{ῦ}ⰂⰲⳊⳋꙆꙇ𐐆𐐮𑢺𑣚 }
\tl_const:cn { c__unicode_fold_6_X_7_tl } { CcǓǔЫыႫⴋᾃ{ἃι}ῧ{ῧ}ⰃⰳⱧⱨ𐐇𐐯𑢻𑣛 }
\tl_const:cn { c__unicode_fold_6_X_8_tl } { DdČčŰűЬьҐґӴӵႬⴌṘṙẼẽᾄ{ἄι}ῨῠⰄⰴⳌⳍꙈꙉ𐐈𐐰𑢼𑣜 }
\tl_const:cn { c__unicode_fold_6_X_9_tl } { EeǕǖЭэႭⴍᾅ{ἅι}ῩῡⰅⰵⱩⱪ𐐉𐐱𑢽𑣝 }
\tl_const:cn { c__unicode_fold_7_X_0_tl } { FfĎďŲųȺⱥЮюҒғӶӷႮⴎṚṛẾếᾆ{ἆι}ῪὺⰆⰶⳎⳏꙊꙋ𐐊𐐲𑢾𑣞 }
\tl_const:cn { c__unicode_fold_7_X_1_tl } { GgǗǘȻȼЯяႯⴏᾇ{ἇι}ΎύⰇⰷⱫⱬ𐐋𐐳𑢿𑣟 }
\tl_const:cn { c__unicode_fold_7_X_2_tl } { HhĐđŴŵҔҕӸӹႰⴐṜṝỀềᾈ{ἀι}ῬῥⰈⰸⳐⳑꙌꙍ𐐌𐐴 }
\tl_const:cn { c__unicode_fold_7_X_3_tl } { IiǙǚȽƚႱⴑᾉ{ἁι}ⰉⰹⱭɑꝹꝺ𐐍𐐵 }
\tl_const:cn { c__unicode_fold_7_X_4_tl } { JjĒēŶŷȾⱦҖҗӺӻႲⴒṞṟỂểᾊ{ἂι}ⰊⰺⱮɱⳒⳓꙎꙏ𐐎𐐶 }
\tl_const:cn { c__unicode_fold_7_X_5_tl } { KkǛǜϏϗႳⴓᾋ{ἃι}ⰋⰻⱯɐꝻꝼ{ﬓ}{մն}𐐏𐐷 }
\tl_const:cn { c__unicode_fold_7_X_6_tl } { LlĔĕŸÿϐβҘҙӼӽႴⴔṠṡỄễἨἠᾌ{ἄι}ⰌⰼⱰɒⳔⳕꙐꙑ{ﬔ}{մե}𐐐𐐸 }
\tl_const:cn { c__unicode_fold_7_X_7_tl } { MmŹźɁɂϑθႵⴕἩἡᾍ{ἅι}ⰍⰽꝽᵹ{ﬕ}{մի}𐐑𐐹 }
\tl_const:cn { c__unicode_fold_7_X_8_tl } { NnĖėǞǟҚқӾӿႶⴖṢṣỆệἪἢᾎ{ἆι}ῲ{ὼι}ⰎⰾⱲⱳⳖⳗꙒꙓꝾꝿ{ﬖ}{վն}𐐒𐐺 }
\tl_const:cn { c__unicode_fold_7_X_9_tl } { OoŻżɃƀႷⴗἫἣᾏ{ἇι}ῳ{ωι}ↃↄⰏⰿ{ﬗ}{մխ}𐐓𐐻 }
\tl_const:cn { c__unicode_fold_8_X_0_tl } { PpĘęǠǡɄʉͰͱҜҝԀԁႸⴘḀḁṤṥỈỉἬἤᾐ{ἠι}ῴ{ώι}ⰐⱀⳘⳙꙔꙕꞀꞁ𐐔𐐼 }
\tl_const:cn { c__unicode_fold_8_X_1_tl } { QqµμŽžɅʌϕφႹⴙἭἥᾑ{ἡι}ⰑⱁⱵⱶ𐐕𐐽 }
\tl_const:cn { c__unicode_fold_8_X_2_tl } { RrĚěǢǣɆɇͲͳϖπҞҟԂԃႺⴚḂḃṦṧỊịἮἦᾒ{ἢι}ῶ{ῶ}ⰒⱂⳚⳛꙖꙗꞂꞃ𐐖𐐾 }
\tl_const:cn { c__unicode_fold_8_X_3_tl } { SsſsႻⴛἯἧᾓ{ἣι}ῷ{ῶι}Ⱃⱃ𐐗𐐿 }
\tl_const:cn { c__unicode_fold_8_X_4_tl } { TtĜĝǤǥɈɉϘϙҠҡԄԅႼⴜḄḅṨṩỌọᾔ{ἤι}ῸὸⰔⱄⳜⳝꙘꙙꞄꞅ𐐘𐑀 }
\tl_const:cn { c__unicode_fold_8_X_5_tl } { UuƁɓႽⴝᾕ{ἥι}ΌόⰕⱅ𐐙𐑁 }
\tl_const:cn { c__unicode_fold_8_X_6_tl } { VvĞğƂƃǦǧɊɋͶͷϚϛҢңԆԇႾⴞḆḇṪṫỎỏᾖ{ἦι}ῺὼΩωⰖⱆⳞⳟꙚꙛꜢꜣꞆꞇ𐐚𐑂 }
\tl_const:cn { c__unicode_fold_8_X_7_tl } { WwႿⴟᾗ{ἧι}ΏώⰗⱇ𐐛𐑃 }
\tl_const:cn { c__unicode_fold_8_X_8_tl } { XxĠġƄƅǨǩɌɍϜϝҤҥԈԉჀⴠḈḉṬṭỐốᾘ{ἠι}ῼ{ωι}ⰘⱈⳠⳡꙜꙝꜤꜥ𐐜𐑄 }
\tl_const:cn { c__unicode_fold_8_X_9_tl } { YyჁⴡᾙ{ἡι}Ⱉⱉ𐐝𐑅 }
\tl_const:cn { c__unicode_fold_9_X_0_tl } { ZzĢģƆɔǪǫɎɏϞϟҦҧԊԋჂⴢḊḋṮṯỒồᾚ{ἢι}KkⰚⱊⱾȿⳢⳣꙞꙟꜦꜧ𐐞𐑆 }
\tl_const:cn { c__unicode_fold_9_X_1_tl } { ƇƈჃⴣᾛ{ἣι}ÅåⰛⱋⱿɀꞋꞌ𐐟𐑇 }
\tl_const:cn { c__unicode_fold_9_X_2_tl } { ÀàĤĥǬǭϠϡҨҩԌԍჄⴤḌḍṰṱỔổἸἰᾜ{ἤι}ⰜⱌⲀⲁꙠꙡꜨꜩ𐐠𐑈 }
\tl_const:cn { c__unicode_fold_9_X_3_tl } { ÁáƉɖჅⴥἹἱᾝ{ἥι}ⰝⱍꞍɥ𐐡𐑉 }
\tl_const:cn { c__unicode_fold_9_X_4_tl } { ÂâĦħƊɗǮǯϢϣҪҫԎԏḎḏṲṳỖỗἺἲᾞ{ἦι}ⰞⱎⲂⲃꙢꙣꜪꜫ𐐢𐑊 }
\tl_const:cn { c__unicode_fold_9_X_5_tl } { ÃãƋƌͿϳჇⴧἻἳᾟ{ἧι}Ⱏⱏ𐐣𐑋 }
\tl_const:cn { c__unicode_fold_9_X_6_tl } { ÄäĨĩǰ{ǰ}ϤϥҬҭԐԑḐḑṴṵỘộἼἴᾠ{ὠι}ⰠⱐⲄⲅꙤꙥꜬꜭꞐꞑ𐐤𐑌 }
\tl_const:cn { c__unicode_fold_9_X_7_tl } { Åå{Ǳ}{ǳ}Ἵἵᾡ{ὡι}Ⱑⱑ𐐥𐑍 }
\tl_const:cn { c__unicode_fold_9_X_8_tl } { ÆæĪīƎǝ{ǲ}{ǳ}ϦϧҮүԒԓḒḓṶṷỚớἾἶᾢ{ὢι}ℲⅎⒶⓐⰢⱒⲆⲇꙦꙧꜮꜯꞒꞓ𐐦𐑎 }
\tl_const:cn { c__unicode_fold_9_X_9_tl } { ÇçƏəἿἷᾣ{ὣι}ⒷⓑⰣⱓⳫⳬ𐐧𐑏 }
